@@ -5,13 +5,10 @@ import shutil
 import click
 import datetime
 
-# from rdflib import Graph, plugin, Literal, RDF, URIRef, Namespace
-# from rdflib.namespace import RDFS, XSD, DC, DCTERMS, VOID
-# from rdflib.serializer import Serializer
-
 from d2s.generate_metadata import create_dataset_prompt, generate_hcls_from_sparql
 from d2s.utils import new_dataset, get_config, init_folder, get_base_dir, init_d2s_java
 from d2s.sparql_operations import sparql_insert_files, java_upload_files
+from d2s.process_datasets import process_datasets_metadata
 
 
 @click.group()
@@ -57,6 +54,42 @@ def create(output):
     create_dataset_prompt(output)
 
 
+@cli.command(help='Download and convert a dataset to RDF based on its metadata file')
+@click.option(
+    '-i', '--input-file', default=None, 
+    help='Input datasets metadata file to process. If not provided d2s will search for a .ttl or .jsonld file in the current folder.')
+# @click.option(
+#     '-o', '--output', default='', 
+#     help='Write RDF to the given output file')
+@click.option(
+    '--dryrun/--publish', default=True, 
+    help='Dry run, only generate RDF and does not publish to a triplestore')
+@click.option(
+    '--staging/--production', default=True, 
+    help='If --publish enabled: publish in the staging triplestore(default), or publish to the production triplestore. And generate metadata about the graph')
+@click.option(
+    '-s', '--sample', default=0, 
+    help='Produce a sample file with given number of lines for TSV/CSV files (e.g. --sample 100).')
+@click.option(
+    '--report/--no-report', default=False, 
+    help='Activate the generation of a HTML report to explore downloaded tabular files')
+@click.option(
+    '-m', '--memory', default='4g', 
+    help='Memory given to the processing, e.g. for java -Xmx. Default: 4g')
+@click.option(
+    '--rmlstreamer/--local', default=False, 
+    help='Activate the generation of a HTML report to explore downloaded tabular files')
+def run(input_file, dryrun, staging, sample, report, memory, rmlstreamer):
+    process_datasets_metadata(input_file, dryrun, staging, sample, report, memory, rmlstreamer)
+    # if output:
+    #     g.serialize(destination=output, format='turtle')
+    #     print("Metadata stored to " + output + ' 📝')
+    # else:
+    #     print(g.serialize(format='turtle'))
+
+
+
+
 @metadata.command(help='Generate HCLS descriptive metadata (about types and relations) for the graphs in a SPARQL endpoint')
 @click.argument('sparql_endpoint')
 @click.option(
@@ -118,6 +151,11 @@ def upload(file_pattern, sparql_endpoint, username, password, graph):
     java_upload_files(file_pattern, sparql_endpoint, username, password, graph)
 
 
+
+
+
+
+
 ### Commands to run services and workflows:
 
 docker_compose_cmd = 'docker-compose '
@@ -238,10 +276,8 @@ def rml(dataset, detached, yarrrml, mapper, openshift, parallelism):
                     # Run rmlmapper docker image
                     init_d2s_java('rmlmapper')
                     output_filename = 'rmlmapper-' + mapping_filename.replace('.', '_') + '-' + dataset + '.nt'
-                    rml_cmd = 'java -jar ' + get_base_dir('sparql-operations.jar') + ' -m ' + dataset + '/mapping/' + mapping_filename + ' -o import/' + output_filename
+                    rml_cmd = 'java -jar ' + get_base_dir('rmlmapper.jar') + ' -m ' + dataset + '/mapping/' + mapping_filename + ' -o import/' + output_filename
                     # rml_cmd = 'docker run ' + detached_arg + ' -v ' + os.getcwd() + '/workspace:/mnt/workspace -v ' + os.getcwd() + '/datasets:/mnt/datasets umids/rmlmapper:4.7.0 -m /mnt/datasets/' + dataset + '/mapping/' + mapping_filename + ' -o /mnt/workspace/import/' + output_filename
-
-                    get_base_dir('sparql-operations.jar')
                 else:
                     # Run RMLStreamer in running Apache Flink
                     output_filename = 'rmlstreamer-' + mapping_filename.replace('.', '_') + '-' + dataset + '.nt'
