@@ -5,28 +5,19 @@ import pathlib
 import urllib.parse
 from datetime import date, datetime
 import pkg_resources
-from rdflib import Graph, plugin, Literal, RDF, XSD, URIRef, Namespace
-from rdflib.namespace import RDFS, DC, DCTERMS, VOID
-from rdflib.serializer import Serializer
+from rdflib import Graph, Literal, RDF, XSD, URIRef, Namespace
+from rdflib.namespace import RDFS, DC, DCTERMS, VOID, SKOS, DCAT, PROV, FOAF
 from SPARQLWrapper import SPARQLWrapper, TURTLE, POST, JSON, JSONLD
 
 DATASET_NAMESPACE = 'https://w3id.org/d2s/dataset/'
 
-RDFS = Namespace("http://www.w3.org/2000/01/rdf-schema#")
-RDF = Namespace("http://www.w3.org/1999/02/22-rdf-syntax-ns#")
-OWL = Namespace("http://www.w3.org/2002/07/owl#")
-SKOS = Namespace("http://www.w3.org/2004/02/skos/core#")
 SCHEMA = Namespace("http://schema.org/")
-DCAT = Namespace("http://www.w3.org/ns/dcat#")
-PROV = Namespace("http://www.w3.org/ns/prov#")
-DC = Namespace("http://purl.org/dc/elements/1.1/")
 DCTYPES = Namespace("http://purl.org/dc/dcmitype/")
 PAV = Namespace("http://purl.org/pav/")
 IDOT = Namespace("http://identifiers.org/idot/")
-FOAF = Namespace("http://xmlns.com/foaf/0.1/")
+D2S = Namespace("https://w3id.org/d2s/vocab/")
 
-
-def create_dataset_prompt():
+def create_dataset_prompt(output_file=None):
     """Create a new dataset from questions asked in the prompt"""
     metadataArray = []
     metadataArray.append({'id': 'dataset_id', 'description': 'Enter the identifier of your datasets, e.g. drugbank (lowercase, no space or weird characters)'})
@@ -57,9 +48,9 @@ def create_dataset_prompt():
 
     g = create_dataset(metadata_answers)
 
-    # if output_file:
-    #     g.serialize(destination=output_file, format='turtle')
-    #     print("Metadata stored to " + output_file + ' 📝')
+    if output_file:
+        g.serialize(destination=output_file, format='turtle')
+        print("Metadata stored to " + output_file + ' 📝')
     # else:
     #     print(g.serialize(format='turtle'))
 
@@ -81,6 +72,8 @@ def create_dataset(metadata):
     g.bind("dcterms", DCTERMS)
     g.bind("pav", PAV)
     g.bind("idot", IDOT)
+    g.bind("void", VOID)
+    g.bind("d2s", D2S)
     # g.bind("owl", OWL)
 
     # Summary
@@ -170,8 +163,8 @@ PREFIX void-ext: <http://ldf.fi/void-ext#>\n"""
         # print(results)
         select_all_graphs_results = results["results"]["bindings"]
     else: 
-        pass
-        # TODO: just query the single provided graph
+        # Just query the single provided graph
+        select_all_graphs_results = [{ 'graph': {'value': str(graph)}}]
 
     # Compute HCLS metadata per graph
     for graph_row in select_all_graphs_results:
@@ -219,8 +212,9 @@ PREFIX void-ext: <http://ldf.fi/void-ext#>\n"""
                     hcls_graph.parse(data=results, format="turtle")
                     g += hcls_graph
                     with open(root / '../REPORT_SUCCESS.md', 'a') as f:
-                        f.write('## Returned RDF \n\n```turtle\n' + results.decode('utf-8') + "\n```\n\n"
-                            + 'Query: \n\n```sparql\n' + complete_query + "\n```\n\n"
+                        # f.write('## Returned RDF \n\n```turtle\n' + results.decode('utf-8') + "\n```\n\n"
+                        f.write('## Successfull query \n\n'
+                            + '```sparql\n' + complete_query + "\n```\n\n"
                             + 'In SPARQL endpoint: ' + sparql_endpoint + "\n\n---\n")
                 except Exception as e:
                     print('SPARQL query failed:')
